@@ -2,12 +2,11 @@ import logging
 
 from datetime import datetime
 from math import copysign
-from jal.constants import Setup, BookAccount, TransactionType, ActionSubtype, TransferSubtype, CorporateAction, \
-    PredefinedCategory, PredefinedPeer
-from PySide2.QtCore import Qt, QDate, QDateTime
+from jal.constants import Setup, BookAccount, TransactionType, TransferSubtype, ActionSubtype, DividendSubtype, \
+    CorporateAction, PredefinedCategory, PredefinedPeer
+from PySide2.QtCore import QDate
 from PySide2.QtWidgets import QDialog, QMessageBox
-from jal.db.helpers import executeSQL, readSQL, readSQLrecord
-from jal.db.routines import calculateBalances, calculateHoldings
+from jal.db.helpers import executeSQL, readSQL, readSQLrecord, get_asset_name
 from jal.ui_custom.helpers import g_tr
 from jal.ui.ui_rebuild_window import Ui_ReBuildDialog
 
@@ -51,65 +50,6 @@ class Ledger:
         self.db = db
         self.current = {}
         self.current_seq = -1
-        self.balances_view = None
-        self.holdings_view = None
-        self.balance_active_only = 1
-        self.balance_currency = None
-        self.balance_date = QDateTime.currentSecsSinceEpoch()
-        self.holdings_date = QDateTime.currentSecsSinceEpoch()
-        self.holdings_currency = None
-
-    def setViews(self, balances, holdings):
-        self.balances_view = balances
-        self.holdings_view = holdings
-
-    def setActiveBalancesOnly(self, active_only):
-        if self.balance_active_only != active_only:
-            self.balance_active_only = active_only
-            self.updateBalancesView()
-
-    def setBalancesDate(self, balance_date):
-        if self.balance_date != balance_date:
-            self.balance_date = balance_date
-            self.updateBalancesView()
-
-    def setBalancesCurrency(self, currency_id, currency_name):
-        if self.balance_currency != currency_id:
-            self.balance_currency = currency_id
-            balances_model = self.balances_view.model()
-            balances_model.setHeaderData(balances_model.fieldIndex("balance_adj"), Qt.Horizontal,
-                                         g_tr('Ledger', "Balance, ") + currency_name)
-            self.updateBalancesView()
-
-    def updateBalancesView(self):
-        if self.balances_view is None:
-            return
-        calculateBalances(self.db, self.balance_date, self.balance_currency, self.balance_active_only)
-        self.balances_view.model().select()
-
-    def setHoldingsDate(self, holdings_date):
-        if self.holdings_date != holdings_date:
-            self.holdings_date = holdings_date
-            self.updateHoldingsView()
-
-    def setHoldingsCurrency(self, currency_id, currency_name):
-        if self.holdings_currency != currency_id:
-            self.holdings_currency = currency_id
-            holidings_model = self.holdings_view.model()
-            holidings_model.setHeaderData(holidings_model.fieldIndex("value_adj"), Qt.Horizontal,
-                                          g_tr('Ledger', "Value, ") + currency_name)
-            self.updateHoldingsView()
-
-    def updateHoldingsView(self):
-        if self.holdings_view is None:
-            return
-        calculateHoldings(self.db, self.holdings_date, self.holdings_currency)
-        holdings_model = self.holdings_view.model()
-        holdings_model.select()
-        for row in range(holdings_model.rowCount()):
-            if holdings_model.data(holdings_model.index(row, 1)):
-                self.holdings_view.setSpan(row, 3, 1, 3)
-        self.holdings_view.show()
 
     # Returns timestamp of last operations that were calculated into ledger
     def getCurrentFrontier(self):
@@ -226,6 +166,10 @@ class Ledger:
             self.appendTransaction(book, -amount)
 
     def processAction(self):
+        if self.current['amount'] == '':
+            logging.warning(g_tr('Ledger', "Can't process operation without details") +
+                            f" @{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d.%m.%Y %H:%M:%S')}")
+            return
         action_amount = self.current['amount']
         if action_amount < 0:
             credit_taken = self.takeCredit(-action_amount)
@@ -242,15 +186,28 @@ class Ledger:
             self.processActionDetails()
 
     def processDividend(self):
+        if self.current['subtype'] == DividendSubtype.Dividend:
+            self.current['category'] = PredefinedCategory.Dividends
+        elif self.current['subtype'] == DividendSubtype.BondInterest:
+            self.current['category'] = PredefinedCategory.Interest
+        else:
+            logging.error(g_tr('Ledger', "Can't process dividend with N/A type"))
+            return
         if self.current['peer'] == '':
             logging.error(g_tr('Ledger', "Can't process dividend as bank isn't set for investment account"))
             return
         dividend_amount = self.current['amount']
         tax_amount = self.current['fee_tax']
-        credit_returned = self.returnCredit(dividend_amount - tax_amount)
-        if credit_returned < dividend_amount:
-            self.appendTransaction(BookAccount.Money, dividend_amount - credit_returned)
-        self.appendTransaction(BookAccount.Incomes, -dividend_amount)
+        if dividend_amount > 0:
+            credit_returned = self.returnCredit(dividend_amount - tax_amount)
+            if credit_returned < (dividend_amount - tax_amount):
+                self.appendTransaction(BookAccount.Money, dividend_amount - credit_returned)
+            self.appendTransaction(BookAccount.Incomes, -dividend_amount)
+        else:
+            credit_taken = self.takeCredit(-dividend_amount - tax_amount)  # tax always positive
+            if credit_taken < -dividend_amount:
+                self.appendTransaction(BookAccount.Money, dividend_amount + credit_taken)
+            self.appendTransaction(BookAccount.Costs, -dividend_amount)
         if tax_amount:
             self.appendTransaction(BookAccount.Money, -tax_amount)
             self.current['category'] = PredefinedCategory.Taxes
@@ -269,7 +226,7 @@ class Ledger:
         qty = type * self.current['amount']
         price = self.current['price']
 
-        trade_value = round(price * qty, 2) + type * self.current['fee_tax'] + self.current['coupon']
+        trade_value = round(price * qty, 2) + type * self.current['fee_tax']
 
         processed_qty = 0
         processed_value = 0
@@ -390,46 +347,59 @@ class Ledger:
             self.appendTransaction(BookAccount.Incomes, type * ((price * processed_qty) - processed_value))
         if processed_qty < qty:  # We have reminder that opens a new position
             self.appendTransaction(BookAccount.Assets, type*(qty - processed_qty), type*(qty - processed_qty) * price)
-        if self.current['coupon']:
-            self.current['category'] = PredefinedCategory.Dividends
-            if type> 0:
-                self.appendTransaction(BookAccount.Costs, self.current['coupon'])
-            else:
-                self.appendTransaction(BookAccount.Incomes, type*self.current['coupon'])
         if self.current['fee_tax']:
             self.current['category'] = PredefinedCategory.Fees
             self.appendTransaction(BookAccount.Costs, self.current['fee_tax'])
 
-    def processTransferOut(self):
-        amount = -self.current['amount']
-        credit_taken = self.takeCredit(amount)
-        self.appendTransaction(BookAccount.Money, -(amount - credit_taken))
-        self.appendTransaction(BookAccount.Transfers, amount)
-
-    def processTransferIn(self):
-        amount = self.current['amount']
-        credit_returned = self.returnCredit(amount)
-        if credit_returned < amount:
-            self.appendTransaction(BookAccount.Money, (amount - credit_returned))
-        self.appendTransaction(BookAccount.Transfers, -amount)
-
-    def processTransferFee(self):
-        fee = -self.current['amount']
-        credit_taken = self.takeCredit(fee)
-        self.current['peer'] = PredefinedPeer.Financial
-        self.appendTransaction(BookAccount.Money, -(fee - credit_taken))
-        self.current['category'] = PredefinedCategory.Fees
-        self.appendTransaction(BookAccount.Costs, fee)
-
     def processTransfer(self):
-        operationTransfer = {
-            TransferSubtype.Outgoing: self.processTransferOut,
-            TransferSubtype.Fee: self.processTransferFee,
-            TransferSubtype.Incoming: self.processTransferIn
-        }
-        operationTransfer[self.current['subtype']]()
+        if self.current['subtype'] == TransferSubtype.Outgoing:
+            credit_taken = self.takeCredit(self.current['amount'])
+            self.appendTransaction(BookAccount.Money, -(self.current['amount'] - credit_taken))
+            self.appendTransaction(BookAccount.Transfers, self.current['amount'])
+        elif self.current['subtype'] == TransferSubtype.Fee:
+            credit_taken = self.takeCredit(self.current['amount'])
+            self.current['peer'] = PredefinedPeer.Financial
+            self.current['category'] = PredefinedCategory.Fees
+            self.appendTransaction(BookAccount.Money, -(self.current['amount'] - credit_taken))
+            self.appendTransaction(BookAccount.Costs, self.current['amount'])
+            self.appendTransaction(BookAccount.Transfers, self.current['amount'])
+        elif self.current['subtype'] == TransferSubtype.Incoming:
+            credit_returned = self.returnCredit(self.current['amount'])
+            if credit_returned < self.current['amount']:
+                self.appendTransaction(BookAccount.Money, (self.current['amount'] - credit_returned))
+            self.appendTransaction(BookAccount.Transfers, -self.current['amount'])
+        else:   # TODO implement assets transfer
+            logging.error(g_tr('Ledger', "Unexpected data in transfer transaction"))
+            return
+
+    def updateStockDividendAssets(self):
+        asset_amount = self.getAmount(BookAccount.Assets, self.current['asset'])
+        self.current['price'] = self.current['price'] + asset_amount
+        self.current['amount'] = asset_amount
+        asset = get_asset_name(self.db, self.current['asset'])
+        QMessageBox().information(None, g_tr('Ledger', "Confirmation"),
+                                  g_tr('Ledger', "Stock dividend for was updated for ") + asset +
+                                  f" @{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d.%m.%Y')}\n" +
+                                  g_tr('Ledger', "Please check that quantity is correct."),
+                                  QMessageBox.Ok)
+        _ = executeSQL(self.db, "DROP TRIGGER IF EXISTS corp_after_update")  # FIXME improve code with triggers
+        _ = executeSQL(self.db, "UPDATE corp_actions SET qty=:qty, qty_new=:qty_new WHERE id=:id",
+                       [(":id", self.current['id']),
+                        (":qty", self.current['amount']), (":qty_new", self.current['price'])])
+        _ = executeSQL(self.db, "CREATE TRIGGER corp_after_update "
+                                "AFTER UPDATE OF timestamp, account_id, type, asset_id, qty, asset_id_new, qty_new "
+                                "ON corp_actions FOR EACH ROW "
+                                "BEGIN "
+                                "DELETE FROM ledger WHERE timestamp >= OLD.timestamp OR timestamp >= NEW.timestamp; "
+                                "DELETE FROM sequence WHERE timestamp >= OLD.timestamp OR timestamp >= NEW.timestamp; "
+                                "DELETE FROM ledger_sums WHERE timestamp >= OLD.timestamp OR timestamp >= NEW.timestamp; "
+                                "END")
 
     def processCorporateAction(self):
+        # Stock dividends are imported without initial stock amounts -> correction happens here
+        if self.current['subtype'] == CorporateAction.StockDividend and self.current['amount'] < 0:
+            self.updateStockDividendAssets()
+
         seq_id = self.current_seq
         account_id = self.current['account']
         asset_id = self.current['asset']
@@ -570,14 +540,18 @@ class Ledger:
         if fast_and_dirty:  # For 30k operations difference of execution time is - with 0:02:41 / without 0:11:44
             _ = executeSQL(self.db, "PRAGMA synchronous = OFF")
         query = executeSQL(self.db, "SELECT type, id, timestamp, subtype, account, currency, asset, amount, "
-                                    "category, price, fee_tax, coupon, peer, tag FROM all_transactions "
+                                    "category, price, fee_tax, peer, tag FROM all_transactions "
                                     "WHERE timestamp >= :frontier", [(":frontier", frontier)])
         while query.next():
             self.current = readSQLrecord(query, named=True)
-            seq_query = executeSQL(self.db, "INSERT INTO sequence(timestamp, type, operation_id) "
-                                            "VALUES(:timestamp, :type, :operation_id)",
+            if self.current['type'] == TransactionType.Action:
+                subtype = copysign(1, self.current['subtype'])
+            else:
+                subtype = self.current['subtype']
+            seq_query = executeSQL(self.db, "INSERT INTO sequence(timestamp, type, subtype, operation_id) "
+                                            "VALUES(:timestamp, :type, :subtype, :operation_id)",
                                    [(":timestamp", self.current['timestamp']), (":type", self.current['type']),
-                                    (":operation_id", self.current['id'])])
+                                    (":subtype", subtype), (":operation_id", self.current['id'])])
             self.current_seq = seq_query.lastInsertId()
             operationProcess[self.current['type']]()
             if not silent and (query.at() % 1000) == 0:
@@ -590,11 +564,10 @@ class Ledger:
         if not silent:
             logging.info(g_tr('Ledger', "Ledger is complete. Elapsed time: ") + f"{datetime.now() - start_time}" +
                          g_tr('Ledger', ", new frontier: ") + f"{datetime.utcfromtimestamp(self.current['timestamp']).strftime('%d/%m/%Y %H:%M:%S')}")
-        self.updateBalancesView()
-        self.updateHoldingsView()
 
     def showRebuildDialog(self, parent):
         rebuild_dialog = RebuildDialog(parent, self.getCurrentFrontier())
         if rebuild_dialog.exec_():
             self.rebuild(from_timestamp=rebuild_dialog.getTimestamp(),
-                         fast_and_dirty=rebuild_dialog.isFastAndDirty(), silent=False)
\ No newline at end of file
+                         fast_and_dirty=rebuild_dialog.isFastAndDirty(), silent=False)
+
