@@ -1,9 +1,9 @@
 from datetime import time, datetime, timedelta, timezone
 
 from jal.constants import ColumnWidth
-from PySide2.QtCore import QCoreApplication, Qt, QStringListModel, QByteArray
+from PySide2.QtCore import QCoreApplication, Qt
 from PySide2.QtSql import QSqlTableModel, QSqlRelationalTableModel, QSqlRelation
-from PySide2.QtWidgets import QHeaderView, QDataWidgetMapper, QFrame, QDateTimeEdit
+from PySide2.QtWidgets import QHeaderView
 
 class hcol_idx:
     DB_NAME = 0
@@ -59,15 +59,6 @@ def formatFloatLong(value):
     return text
 
 
-# -----------------------------------------------------------------------------------------------------------------------
-# a simple VLine, like the one from Qt Designer to use in Status Bar for example
-class VLine(QFrame):
-    def __init__(self):
-        super(VLine, self).__init__()
-        self.setFrameShape(QFrame.VLine)
-        self.setFrameShadow(QFrame.Sunken)
-
-
 # -----------------------------------------------------------------------------------------------------------------------
 # Helpers to work with datetime
 class ManipulateDate:
@@ -189,34 +180,6 @@ def UseSqlQuery(parent, query, columns):
             model.setHeaderData(model.fieldIndex(column[hcol_idx.DB_NAME]), Qt.Horizontal, column[hcol_idx.DISPLAY_NAME])
     return model
 
-# -------------------------------------------------------------------------------------------------------------------
-# Use mappings to link between DB fields and GUI widgets with help of delegate
-# mapping is a list of tuples [(FIELD_NAME, GUI_WIDGET)]
-# If widget is a custom one:
-#    - initialize database connection for it
-#    - connect "changed" signal to "submit" slot of QDataWidgetMapper (to reflect data changes in UI)
-def ConfigureDataMappers(model, mappings, delegate):
-    mapper = QDataWidgetMapper(model)
-    mapper.setModel(model)
-    mapper.setSubmitPolicy(QDataWidgetMapper.AutoSubmit)
-    mapper.setItemDelegate(delegate(mapper))
-    for mapping in mappings:
-        if hasattr(mapping[map_idx.WIDGET], "isCustom"):
-            mapping[map_idx.WIDGET].init_db(model.database())
-            mapping[map_idx.WIDGET].changed.connect(mapper.submit)
-        if mapping[map_idx.WIDGET].property("stringModelData") is not None:
-            # Load lookup values from dynamic property into combo-box model
-            comboModel = QStringListModel(mapping[map_idx.WIDGET].property("stringModelData").split(';'))
-            mapping[map_idx.WIDGET].setModel(comboModel)
-            mapper.addMapping(mapping[map_idx.WIDGET], model.fieldIndex(mapping[map_idx.DB_NAME]),
-                              QByteArray().setRawData("currentIndex", 12))
-        else:  # ComboBox has no USER property so we use QByteArray above, and simple mapping for others below
-            mapper.addMapping(mapping[map_idx.WIDGET], model.fieldIndex(mapping[map_idx.DB_NAME]))
-        # adjust width of QDateTimeEdits to show full date-time string
-        if isinstance(mapping[map_idx.WIDGET], QDateTimeEdit):
-            mapping[map_idx.WIDGET].setFixedWidth(
-                mapping[map_idx.WIDGET].fontMetrics().width("00/00/0000 00:00:00") * 1.25)
-    return mapper
 
 # -------------------------------------------------------------------------------------------------------------------
 # Return value is a list of delegates because storage of delegates
